@@ -1,9 +1,11 @@
 #!/usr/bin/env xonsh
 
-import re
+import re, subprocess
 from tokenize_output.tokenize_output import tokenize_output
 
+_key_meta = __xonsh__.env.get('XONTRIB_OUTPUT_SEARCH_KEY_META', 'escape')
 _key = __xonsh__.env.get('XONTRIB_OUTPUT_SEARCH_KEY', 'f')
+_key_binding = __xonsh__.env.get('XONTRIB_OUTPUT_SEARCH_KEY_BINDING', None)
 _add_previous_cmd_to_output = True
 _support_special_chars_in_prefix = True
 
@@ -54,9 +56,19 @@ def _xontrib_output_search_completer(prefix, line, begidx, endidx, ctx):
 __xonsh__.completers['xontrib_output_search'] = _xontrib_output_search_completer
 __xonsh__.completers.move_to_end('xontrib_output_search', last=False)
 
+def _tmux_current_pane_contents():
+    if not "TMUX" in __xonsh__.env:
+        return None
+    else:
+        try:
+            return subprocess.check_output(["tmux", "capture-pane", "-p"], timeout=1).decode()
+        except:
+            return None
+
 _color_regexp = re.compile(r'(\x9B|\x1B\[)[0-?]*[ -/]*[@-~]')
 @events.on_postcommand
 def _save_output(cmd: str, rtn: int, out: str or None, ts: list, **kwargs):
+    out = out or _tmux_current_pane_contents()
     if out is not None:
         out = out.strip()
         if out:
@@ -70,7 +82,9 @@ try:
         else:
             handler = bindings.registry.add_binding
 
-        @bindings.add('escape', _key)
+        bind = (_key_binding,) if _key_binding else (_key_meta, _key)
+
+        @bindings.add(*bind)
         def _(event):
             if __xonsh__.xontrib_output_search_previous_output is not None:
                 __xonsh__.xontrib_output_search_completion=True
